@@ -62,10 +62,10 @@
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
 #include <netinet/igmp.h>
-#ifdef __FreeBSD__      /* sigh */
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #include <osreldate.h>
 #endif /* __FreeBSD__ */
-#if (defined(__bsdi__)) || (defined(__FreeBSD__) && (__FreeBSD_version >= 220000))
+#if defined(__bsdi__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 #define rtentry kernel_rtentry
 #include <net/route.h>
 #undef rtentry
@@ -154,6 +154,8 @@ typedef void (*ihfunc_t) (int, fd_set *);
 #define min(a, b)               ((a) > (b) ? (b) : (a))
 #endif
 
+#define ENABLINGSTR(bool)       (bool) ? "enabling" : "disabling"
+
 /*
  * Various definitions to make it working for different platforms
  */
@@ -164,7 +166,7 @@ typedef void (*ihfunc_t) (int, fd_set *);
 
 /* Versions of Solaris older than 2.6 don't have routing sockets. */
 /* XXX TODO: check FreeBSD version and add all other platforms */
-#if defined(__linux__) || (defined(SunOS) && SunOS >=56) || defined (__FreeBSD__) || defined (IRIX) || defined (__bsdi__) || defined(NetBSD) || defined(OpenBSD)
+#if defined(__linux__) || (defined(SunOS) && SunOS >=56) || defined (__FreeBSD__) || defined(__FreeBSD_kernel__) || defined (IRIX) || defined (__bsdi__) || defined(NetBSD) || defined(OpenBSD)
 #define HAVE_ROUTING_SOCKETS	1
 #endif
 
@@ -245,7 +247,6 @@ typedef void (*ihfunc_t) (int, fd_set *);
 #endif /* RSRR */
 
 #ifdef SYSV
-#define bcopy(a, b, c)		memcpy((b), (a), (c))
 #define setlinebuf(s)		setvbuf((s), (NULL), (_IOLBF), 0)
 #define RANDOM()                lrand48()
 #else
@@ -349,8 +350,6 @@ extern char		s4[MAX_INET_BUF_LEN];
 
 #if !((defined(BSD) && (BSD >= 199103)) || (defined(__linux__)))
 extern int		errno;
-extern int		sys_nerr;
-extern char *		sys_errlist[];
 #endif
 
 
@@ -407,16 +406,16 @@ extern char *		sys_errlist[];
 
 #define ELSE else           /* To make emacs cc-mode happy */      
 
-#define MASK_TO_VAL(x, i) { \
-			u_int32 _x = ntohl(x); \
-			(i) = 1; \
-			while ((_x) <<= 1) \
-				(i)++; \
-			};
+#define MASK_TO_VAL(x, i) {		   \
+	u_int32 _x = ntohl(x);		   \
+	(i) = 1;			   \
+	while ((_x) <<= 1)		   \
+	    (i)++;			   \
+    };
 
-#define VAL_TO_MASK(x, i) { \
-			x = htonl(~((1 << (32 - (i))) - 1)); \
-			};
+#define VAL_TO_MASK(x, i) {			\
+	x = htonl(~((1 << (32 - (i))) - 1));	\
+    };
 
 /*
  * External function definitions
@@ -492,7 +491,7 @@ extern int	k_del_mfc		(int socket, u_int32 source, u_int32 group);
 extern int	k_chg_mfc		(int socket, u_int32 source, u_int32 group, vifi_t iif, vifbitmap_t oifs,
                                          u_int32 rp_addr);
 extern void	k_add_vif		(int socket, vifi_t vifi, struct uvif *v);
-extern void	k_del_vif		(int socket, vifi_t vifi);
+extern void	k_del_vif		(int socket, vifi_t vifi, struct uvif *v);
 extern int	k_get_vif_count		(vifi_t vifi, struct vif_count *retval);
 extern int	k_get_sg_cnt		(int socket, u_int32 source, u_int32 group, struct sg_count *retval);
 
@@ -639,3 +638,12 @@ int pidfile(const char *basename);
 #endif
 
 #endif /* __PIMD_DEFS_H__ */
+
+/**
+ * Local Variables:
+ *  version-control: t
+ *  indent-tabs-mode: t
+ *  c-file-style: "ellemtel"
+ *  c-basic-offset: 4
+ * End:
+ */
